RepositoryChangeStatusWithError

Enum RepositoryChangeStatusWithError 

pub enum RepositoryChangeStatusWithError {
    UpToDate,
    NoRepository,
    UncommittedChanges {
        num_changes: usize,
    },
    Error {
        reason: GrassError,
    },
    Unknown,
}
Describes the status of a repository.

The status is related to whether or not there are changes.

Variants



UpToDate

All changes have been committed.



NoRepository

No repository has been initialized.



UncommittedChanges

A repository has been initialized, but there are uncommitted changes.

num_changes is not strongly defined, this number may change between versions. It has no real meaning, and should only be used for generic estimates.

Fields

num_changes: usize


Error

The status is unkown due to an error.

Fields

reason: GrassError


Unknown

This repository has an unknown status.

This is only applicable if the unkown status is within the expected behavior of the implementation. For example, if an implementation has to synchronize in the background, then it may result in an unkown status.

This means that unknown doesn’t mean something is wrong, although it may be. If the status is unknown due to an error, use Error1 instead.


  1. [crate::dev::strategy::git::RepositoryChangeStatus::Error]