pub struct Category(pub String);Expand description
A string which represents a category.
This is a unique type, because not all conversion to a String make sense.
For example, take Alias1.
If this were converted to a std::str,
then something like “{alias} -> {category}” would make more sense.
But when used as a category, just the category should be used.
Tuple Fields
0: StringTrait Implementations
Sourceimpl From<ResolveAliasResult> for Category
impl From<ResolveAliasResult> for Category
Sourcefn from(value: ResolveAliasResult) -> Self
fn from(value: ResolveAliasResult) -> Self
Converts to this type from the input type.
Sourceimpl Ord for Category
impl Ord for Category
Sourceimpl PartialOrd for Category
impl PartialOrd for Category
impl Eq for Category
impl StructuralPartialEq for Category